package h

import (
	gh "maragu.dev/gomponents/html"
)

func A(children ...H) H {
	return gh.A(retype(children)...)
}

func Abbr(children ...H) H {
	return gh.Abbr(retype(children)...)
}

func Address(children ...H) H {
	return gh.Address(retype(children)...)
}

func Area(children ...H) H {
	return gh.Area(retype(children)...)
}

func Article(children ...H) H {
	return gh.Article(retype(children)...)
}

func Aside(children ...H) H {
	return gh.Aside(retype(children)...)
}

func Audio(children ...H) H {
	return gh.Audio(retype(children)...)
}

func B(children ...H) H {
	return gh.B(retype(children)...)
}

func Base(children ...H) H {
	return gh.Base(retype(children)...)
}

func BlockQuote(children ...H) H {
	return gh.BlockQuote(retype(children)...)
}

func Body(children ...H) H {
	return gh.Body(retype(children)...)
}

func Br(children ...H) H {
	return gh.Br(retype(children)...)
}

func Button(children ...H) H {
	return gh.Button(retype(children)...)
}

func Canvas(children ...H) H {
	return gh.Canvas(retype(children)...)
}

func Caption(children ...H) H {
	return gh.Caption(retype(children)...)
}

func Cite(children ...H) H {
	return gh.Cite(retype(children)...)
}

func Code(children ...H) H {
	return gh.Code(retype(children)...)
}

func Col(children ...H) H {
	return gh.Col(retype(children)...)
}

func ColGroup(children ...H) H {
	return gh.ColGroup(retype(children)...)
}

func DataList(children ...H) H {
	return gh.DataList(retype(children)...)
}

func Dd(children ...H) H {
	return gh.Dd(retype(children)...)
}

func Del(children ...H) H {
	return gh.Del(retype(children)...)
}

func Details(children ...H) H {
	return gh.Details(retype(children)...)
}

func Dfn(children ...H) H {
	return gh.Dfn(retype(children)...)
}

func Dialog(children ...H) H {
	return gh.Dialog(retype(children)...)
}

func Div(children ...H) H {
	return gh.Div(retype(children)...)
}

func Dl(children ...H) H {
	return gh.Dl(retype(children)...)
}

func Dt(children ...H) H {
	return gh.Dt(retype(children)...)
}

func Em(children ...H) H {
	return gh.Em(retype(children)...)
}

func Embed(children ...H) H {
	return gh.Embed(retype(children)...)
}

func FieldSet(children ...H) H {
	return gh.FieldSet(retype(children)...)
}

func FigCaption(children ...H) H {
	return gh.FigCaption(retype(children)...)
}

func Figure(children ...H) H {
	return gh.Figure(retype(children)...)
}

func Footer(children ...H) H {
	return gh.Footer(retype(children)...)
}

func Form(children ...H) H {
	return gh.Form(retype(children)...)
}

func H1(children ...H) H {
	return gh.H1(retype(children)...)
}

func H2(children ...H) H {
	return gh.H2(retype(children)...)
}

func H3(children ...H) H {
	return gh.H3(retype(children)...)
}

func H4(children ...H) H {
	return gh.H4(retype(children)...)
}

func H5(children ...H) H {
	return gh.H5(retype(children)...)
}

func H6(children ...H) H {
	return gh.H6(retype(children)...)
}

func Head(children ...H) H {
	return gh.Head(retype(children)...)
}

func Header(children ...H) H {
	return gh.Header(retype(children)...)
}

func Hr(children ...H) H {
	return gh.Hr(retype(children)...)
}

func HTML(children ...H) H {
	return gh.HTML(retype(children)...)
}

func I(children ...H) H {
	return gh.I(retype(children)...)
}

func IFrame(children ...H) H {
	return gh.IFrame(retype(children)...)
}

func Img(children ...H) H {
	return gh.Img(retype(children)...)
}

func Input(children ...H) H {
	return gh.Input(retype(children)...)
}

func Ins(children ...H) H {
	return gh.Ins(retype(children)...)
}

func Kbd(children ...H) H {
	return gh.Kbd(retype(children)...)
}

func Label(children ...H) H {
	return gh.Label(retype(children)...)
}

func Legend(children ...H) H {
	return gh.Legend(retype(children)...)
}

func Li(children ...H) H {
	return gh.Li(retype(children)...)
}

func Link(children ...H) H {
	return gh.Link(retype(children)...)
}

func Main(children ...H) H {
	return gh.Main(retype(children)...)
}

func Mark(children ...H) H {
	return gh.Mark(retype(children)...)
}

func Meta(children ...H) H {
	return gh.Meta(retype(children)...)
}

func Meter(children ...H) H {
	return gh.Meter(retype(children)...)
}

func Nav(children ...H) H {
	return gh.Nav(retype(children)...)
}

func NoScript(children ...H) H {
	return gh.NoScript(retype(children)...)
}

func Object(children ...H) H {
	return gh.Object(retype(children)...)
}

func Ol(children ...H) H {
	return gh.Ol(retype(children)...)
}

func OptGroup(children ...H) H {
	return gh.OptGroup(retype(children)...)
}

func Option(children ...H) H {
	return gh.Option(retype(children)...)
}

func P(children ...H) H {
	return gh.P(retype(children)...)
}

func Picture(children ...H) H {
	return gh.Picture(retype(children)...)
}

func Pre(children ...H) H {
	return gh.Pre(retype(children)...)
}

func Progress(children ...H) H {
	return gh.Progress(retype(children)...)
}

func Q(children ...H) H {
	return gh.Q(retype(children)...)
}

func S(children ...H) H {
	return gh.S(retype(children)...)
}

func Samp(children ...H) H {
	return gh.Samp(retype(children)...)
}

func Script(children ...H) H {
	return gh.Script(retype(children)...)
}

func Section(children ...H) H {
	return gh.Section(retype(children)...)
}

func Select(children ...H) H {
	return gh.Select(retype(children)...)
}

func Small(children ...H) H {
	return gh.Small(retype(children)...)
}

func Source(children ...H) H {
	return gh.Source(retype(children)...)
}

func Span(children ...H) H {
	return gh.Span(retype(children)...)
}

func Strong(children ...H) H {
	return gh.Strong(retype(children)...)
}

func Style(v string) H {
	return gh.Style(v)
}

func Sub(children ...H) H {
	return gh.Sub(retype(children)...)
}

func Summary(children ...H) H {
	return gh.Summary(retype(children)...)
}

func Sup(children ...H) H {
	return gh.Sup(retype(children)...)
}

func Table(children ...H) H {
	return gh.Table(retype(children)...)
}

func TBody(children ...H) H {
	return gh.TBody(retype(children)...)
}

func Td(children ...H) H {
	return gh.Td(retype(children)...)
}

func Template(children ...H) H {
	return gh.Template(retype(children)...)
}

func Textarea(children ...H) H {
	return gh.Textarea(retype(children)...)
}

func TFoot(children ...H) H {
	return gh.TFoot(retype(children)...)
}

func Th(children ...H) H {
	return gh.Th(retype(children)...)
}

func THead(children ...H) H {
	return gh.THead(retype(children)...)
}

func Time(children ...H) H {
	return gh.Time(retype(children)...)
}

func Title(v string) H {
	return gh.Title(v)
}

func Tr(children ...H) H {
	return gh.Tr(retype(children)...)
}

func U(children ...H) H {
	return gh.U(retype(children)...)
}

func Ul(children ...H) H {
	return gh.Ul(retype(children)...)
}

func Var(children ...H) H {
	return gh.Var(retype(children)...)
}

func StyleEl(children ...H) H {
	return gh.StyleEl(retype(children)...)
}

func Video(children ...H) H {
	return gh.Video(retype(children)...)
}

func Wbr(children ...H) H {
	return gh.Wbr(retype(children)...)
}
